{
  description = "Neovim plugin for Unicode character conceal via tree-sitter";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixpkgs-unstable";
  };

  outputs = { self, nixpkgs, ... }@inputs:
    let
      name = "nvim-tree-sitter-unicode-conceal";

      # neovim ∪ tree-sitter
      supportedSystems = [
        "aarch64-linux"
        "i686-linux"
        "x86_64-linux"
        "aarch64-darwin"
        "x86_64-darwin"
      ];

      forAllSystems = nixpkgs.lib.genAttrs supportedSystems;

      nixpkgsFor = forAllSystems (system: import nixpkgs {
        inherit system;
        config = {
          allowlistedLicenses = with nixpkgs.lib.licenses; [
          ];
        };
        overlays = [ self.overlays.vimPlugins ];
      });
    in
    {
      overlays = {
        vimPlugins = final: prev: {
          vimPlugins = prev.vimPlugins // { ${name} = self.packages.${prev.system}.${name}; };
        };
      };

      packages = forAllSystems (system:
        let pkgs = nixpkgsFor.${system}; inherit (pkgs) lib; in {
          default = self.packages.${system}.${name};

          ${name} = pkgs.vimUtils.buildVimPlugin {
            inherit name;
            namePrefix = "";
            src = lib.fileset.toSource {
              root = ./.;
              fileset = lib.fileset.unions [
                ./after
                ./COPYING.txt
                ./COPYING.LESSER.txt
              ];
            };
            meta = {
              license = lib.licenses.lgpl21;
            };
          };

          nvim-mod = pkgs.neovim.override {
            configure = {
              packages.myPlugins = with pkgs.vimPlugins; {
                start = [
                  lsp_lines-nvim
                  trouble-nvim
                  (nvim-treesitter.withPlugins (
                    plugins: with plugins; [
                      erlang
                      fish
                      lua
                      nickel
                      nix
                      ocaml
                      ocaml-interface
                      php
                    ]
                  ))
                  playground
                  self.packages."${system}"."${name}"
                ];
              };
              customRC = ''
                syntax off
                set tabstop=4
                set shiftwidth=4
                set conceallevel=2
                let mapleader=' '
                let maplocalleader='-'

                autocmd BufNewFile,BufRead *.ncl setfiletype nickel
                autocmd BufNewFile,BufRead *.nix setfiletype nix

                lua <<EOF
                require('nvim-treesitter.configs').setup({
                  highlight = {
                    enable = true,
                  },
                })
                require("lsp_lines").setup()
                require("trouble").setup({
                  height = 9,
                  fold_open = "▶",
                  fold_close = "▼",
                  padding = false,
                  auto_close = true,
                  signs = {
                    error = "☠",
                    warning = "‼",
                    hint = "✽",
                    information = "ℹ",
                    other = "⁇",
                  },
                  use_diagnostic_signs = true,
                })

                vim.keymap.set("n", "<leader>xx", "<cmd>TroubleToggle<cr>",
                  {silent = true, noremap = true}
                )
                vim.keymap.set("n", "<leader>xw", "<cmd>TroubleToggle workspace_diagnostics<cr>",
                  {silent = true, noremap = true}
                )
                vim.keymap.set("n", "<leader>xd", "<cmd>TroubleToggle document_diagnostics<cr>",
                  {silent = true, noremap = true}
                )
                vim.keymap.set("n", "<leader>xl", "<cmd>TroubleToggle loclist<cr>",
                  {silent = true, noremap = true}
                )
                vim.keymap.set("n", "<leader>xq", "<cmd>TroubleToggle quickfix<cr>",
                  {silent = true, noremap = true}
                )
                vim.keymap.set("n", "gR", "<cmd>TroubleToggle lsp_references<cr>",
                  {silent = true, noremap = true}
                )
                EOF
              '';
            };
          };
        });

      apps = forAllSystems (system:
        let pkgs = nixpkgsFor.${system}; in {
          default = self.apps.${system}.nvim-mod;

          nvim-mod = {
            type = "app";
            program = "${self.packages.${system}.nvim-mod}/bin/nvim";
          };
        });

      devShells = forAllSystems (system:
        let pkgs = nixpkgsFor.${system}; in
        {
          ${name} = pkgs.mkShell {
            inherit name;
            buildInputs = with pkgs; [
              nixpkgs-fmt
              topiary
            ];
          };

          default = self.devShells.${system}.${name};
        });
    };
}
